# Generated by roxygen2: do not edit by hand

S3method(prepare_data,character)
S3method(prepare_data,data.frame)
S3method(print,corporaexplorerobject)
export("%>%")
export(create_janeausten_app)
export(create_sotu_app)
export(create_sotu_decade_app)
export(explore)
export(explore0)
export(prepare_data)
export(run_corpus_explorer)
export(run_document_extractor)
export(run_janeausten_app)
export(run_sotu_app)
export(run_sotu_decade_app)
import(data.table, except = ":=")
import(rlang)
importFrom(magrittr,"%>%")
