# library(shiny)
# library(shinydashboard)
# 
# library(shinyWidgets)
# 
# library(stringr)
# library(dplyr)
# library(readr)
# library(data.table)
# library(shinyjs)
# 
# library(ipc)
# library(promises)
# library(future)

# library(magrittr)  # TODO Remove in package

# future_plan <- "sequential"

# strategy <- "future::multisession"
# future::plan(strategy)  #(multicore)  # Ikke bruk plan() i package
